summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/lib/manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/lib/manager.h')
-rw-r--r--kexi/plugins/macros/lib/manager.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kexi/plugins/macros/lib/manager.h b/kexi/plugins/macros/lib/manager.h
index 964f9d7c..fb332f66 100644
--- a/kexi/plugins/macros/lib/manager.h
+++ b/kexi/plugins/macros/lib/manager.h
@@ -20,16 +20,16 @@
#ifndef KOMACRO_MANAGER_H
#define KOMACRO_MANAGER_H
-#include <qmap.h>
-#include <qguardedptr.h>
+#include <tqmap.h>
+#include <tqguardedptr.h>
#include <ksharedptr.h>
#include <kxmlguiclient.h>
#include <kstaticdeleter.h>
#include "komacro_export.h"
-class QObject;
-class QDomElement;
+class TQObject;
+class TQDomElement;
namespace KoMacro {
@@ -42,11 +42,11 @@ namespace KoMacro {
*
* Example how KoMacro could be used.
* @code
* // We have a class that inheritates from QObject and
* // implements some public signals and slots that will
* // be accessible by Macros once a class-instance
* // got published.
- * class PublishedObject : public QObject {};
+ * class PublishedObject : public TQObject {};
*
* // Somewhere we have our KMainWindow.
* KMainWindow* mainwindow = new KMainWindow();
@@ -55,7 +55,7 @@ namespace KoMacro {
* // Macro-framework.
* KoMacro::Manager* manager = new KoMacro::Manager( mainwindow );
*
* // Now we like to publish a QObject
* PublishedObject* publishedobject = new PublishedObject();
* manager->publishObject(publishedobject);
*
@@ -64,7 +64,7 @@ namespace KoMacro {
*
* // Finally free the publishedobject instance we created. We
* // need to free it manualy cause PublishedObject doesn't
* // got a QObject parent as argument.
* delete publishedobject;
*
* // Finally free the manager-instance. It's always needed
@@ -116,32 +116,32 @@ namespace KoMacro {
* \return true if we carry a \a Macro with the
* defined \p macroname .
*/
- bool hasMacro(const QString& macroname);
+ bool hasMacro(const TQString& macroname);
/**
* \return the \a Macro defined with \p macroname
* or NULL if we don't have such a \a Macro.
*/
- KSharedPtr<Macro> getMacro(const QString& macroname);
+ KSharedPtr<Macro> getMacro(const TQString& macroname);
/**
* Add a new \a Macro to the list of known macros. If
* there exists already a \a Macro instance with the
* defined \p macroname then the already existing one
- * will be replace.
+ * will be tqreplace.
*
* \param macroname The name the \a Macro will be
* accessible as.
* \param macro The \a Macro instance.
*/
- void addMacro(const QString& macroname, KSharedPtr<Macro> macro);
+ void addMacro(const TQString& macroname, KSharedPtr<Macro> macro);
/**
* Remove the \a Macro defined with \p macroname . If
* we don't know about a \a Macro with that \p macroname
* nothing happens.
*/
- void removeMacro(const QString& macroname);
+ void removeMacro(const TQString& macroname);
/**
* Factory function to create a new \a Macro instances.
@@ -150,21 +150,21 @@ namespace KoMacro {
* like to attach the returned new \a Macro to this
* \a Manager instance.
*/
- KSharedPtr<Macro> createMacro(const QString& macroname);
+ KSharedPtr<Macro> createMacro(const TQString& macroname);
#if 0
/**
* Factory method to create @a Action instances from the
* defined @p element .
*
* @param element The serialized QDomElement that should
* be used to create the @a Action instance.
* @return A new @a Action instance or NULL if the
* defined @p element is not valid.
*
* @deprecated Moved to common XMLReader/XMLWriter classes. Use Macro::xmlHandler() !
*/
- KSharedPtr<Action> createAction(const QDomElement& element);
+ KSharedPtr<Action> createAction(const TQDomElement& element);
#endif
/**
@@ -172,17 +172,17 @@ namespace KoMacro {
* name @p name or returns an empty @a KSharedPtr<Action> object
* if there was no such @a Action published.
*/
- KSharedPtr<Action> action(const QString& name) const;
+ KSharedPtr<Action> action(const TQString& name) const;
/**
* @return a map of all published actions.
*/
- QMap<QString, KSharedPtr<Action> > actions() const;
+ TQMap<TQString, KSharedPtr<Action> > actions() const;
/**
* @return a list of all published actions.
*/
- QStringList actionNames() const;
+ TQStringList actionNames() const;
/**
* Publish the @a Action @p action . The published @a Action
@@ -191,21 +191,21 @@ namespace KoMacro {
void publishAction(KSharedPtr<Action> action);
/**
* Publish the passed QObject @p object. Those object will
* provide it's slots as callable functions.
*/
- void publishObject(const QString& name, QObject* object);
+ void publishObject(const TQString& name, TQObject* object);
/**
* @return the publish QObject defined with name @p name
* or NULL if there exists no such object.
*/
- QGuardedPtr<QObject> object(const QString& name) const;
+ TQGuardedPtr<TQObject> object(const TQString& name) const;
/**
* @return a map of the published QObject instances.
*/
- QMap<QString, QGuardedPtr<QObject> > objects() const;
+ TQMap<TQString, TQGuardedPtr<TQObject> > objects() const;
private:
/// @internal d-pointer class.
@@ -42,11 +42,11 @@ namespace KoMacro {
* Example how KoMacro could be used.
* @code
- * // We have a class that inheritates from QObject and
+ * // We have a class that inheritates from TQObject and
* // implements some public signals and slots that will
* // be accessible by Macros once a class-instance
@@ -55,7 +55,7 @@ namespace KoMacro {
* KoMacro::Manager* manager = new KoMacro::Manager( mainwindow );
*
- * // Now we like to publish a QObject
+ * // Now we like to publish a TQObject
* PublishedObject* publishedobject = new PublishedObject();
* manager->publishObject(publishedobject);
@@ -64,7 +64,7 @@ namespace KoMacro {
* // Finally free the publishedobject instance we created. We
* // need to free it manualy cause PublishedObject doesn't
- * // got a QObject parent as argument.
+ * // got a TQObject tqparent as argument.
* delete publishedobject;
*
@@ -150,21 +150,21 @@ namespace KoMacro {
* defined @p element .
*
- * @param element The serialized QDomElement that should
+ * @param element The serialized TQDomElement that should
* be used to create the @a Action instance.
* @return A new @a Action instance or NULL if the
@@ -191,21 +191,21 @@ namespace KoMacro {
void publishAction(KSharedPtr<Action> action);
/**
- * Publish the passed QObject @p object. Those object will
+ * Publish the passed TQObject @p object. Those object will
* provide it's slots as callable functions.
*/
@@ -191,21 +191,21 @@ namespace KoMacro {
/**
- * @return the publish QObject defined with name @p name
+ * @return the publish TQObject defined with name @p name
* or NULL if there exists no such object.
*/
@@ -191,21 +191,21 @@ namespace KoMacro {
/**
- * @return a map of the published QObject instances.
+ * @return a map of the published TQObject instances.
*/